# tfscc3d

Replacements for tf.contrib.feature_column.sequence_categorical_column_with_hash_bucket and tf.contrib.feature_column.sequence_categorical_column_with_vocabulary_list that supports 3D shape sequence inputs.


## Usage

Same as original sequence feature columns.